==> AGXUnreal-1.17.0_UE-5.4_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics/Interactions/Dissipation/ConstantViscousSurfaceFriction.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/Interactions/Dissipation/DefaultFriction.h>
/* Generated code for model ConstantViscousSurfaceFriction */
namespace openplx::Physics::Interactions::Dissipation {
    /**
     *     Use the ConstantViscousSurfaceFriction to specify the a viscous friction model
     *     with constant viscosity between two surfaces.
     *
     *     The unit for the surface viscosity is [N * s / m] or [Pa * s / m]
     *
     *     The viscosity is only valid for values >= 0.
     *     If set to infinity, a rigid coupling is assumed.
     *     */
    class ConstantViscousSurfaceFriction : public openplx::Physics::Interactions::Dissipation::DefaultFriction {
        protected:
            double m_viscosity;

        public:
            ConstantViscousSurfaceFriction();
            double viscosity() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.7_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics/Interactions/Dissipation/ConstantViscousSurfaceFriction.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics/PhysicsBundleExport.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/Interactions/Dissipation/DefaultFriction.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model ConstantViscousSurfaceFriction */
namespace openplx::Physics::Interactions::Dissipation {
    /**
     *     Use the ConstantViscousSurfaceFriction to specify the a viscous friction model
     *     with constant viscosity between two surfaces.
     *
     *     The unit for the surface viscosity is [N * s / m] or [Pa * s / m]
     *
     *     The viscosity is only valid for values >= 0.
     *     If set to infinity, a rigid coupling is assumed.
     *     */
    class OPENPLX_Physics_BUNDLE_EXPORT ConstantViscousSurfaceFriction : public openplx::Physics::Interactions::Dissipation::DefaultFriction {
        protected:
            double m_viscosity;

        public:
            ConstantViscousSurfaceFriction();
            virtual ~ConstantViscousSurfaceFriction();
            double viscosity() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
